@@ -3,6 +3,6 @@ from forms import FieldSanitizerAdminForm
 from models import FieldSanitizer
 
 class FieldSanitizerAdmin(admin.ModelAdmin):
-    list_display = ('content_type', 'field_name', ) 
+    list_display = ('content_type', 'app_name', 'model_name', 'field_name', ) 
     form = FieldSanitizerAdminForm
 admin.site.register(FieldSanitizer, FieldSanitizerAdmin)
